// Main JavaScript File

document.addEventListener('DOMContentLoaded', function() {
  // Form Validation
  const forms = document.querySelectorAll('form');
  forms.forEach(form => {
    form.addEventListener('submit', validateForm);
  });

  // Appointment Scheduling
  const appointmentForm = document.getElementById('appointment-form');
  if (appointmentForm) {
    appointmentForm.addEventListener('submit', handleAppointmentSubmit);
  }

  // File Upload Preview
  const fileInputs = document.querySelectorAll('input[type="file"]');
  fileInputs.forEach(input => {
    input.addEventListener('change', handleFilePreview);
  });
});

// Form Validation Function
function validateForm(e) {
  let isValid = true;
  const requiredFields = e.target.querySelectorAll('[required]');

  requiredFields.forEach(field => {
    if (!field.value.trim()) {
      isValid = false;
      showError(field, 'This field is required');
    } else {
      removeError(field);
    }
  });

  if (!isValid) {
    e.preventDefault();
  }
}

// Show Error Message
function showError(field, message) {
  const existingError = field.parentElement.querySelector('.error-message');
  if (!existingError) {
    const errorDiv = document.createElement('div');
    errorDiv.className = 'error-message';
    errorDiv.style.color = 'red';
    errorDiv.style.fontSize = '0.8rem';
    errorDiv.textContent = message;
    field.parentElement.appendChild(errorDiv);
  }
  field.style.borderColor = 'red';
}

// Remove Error Message
function removeError(field) {
  const error = field.parentElement.querySelector('.error-message');
  if (error) {
    error.remove();
  }
  field.style.borderColor = '';
}

// Handle Appointment Submit
function handleAppointmentSubmit(e) {
  e.preventDefault();

  // Get form data
  const formData = new FormData(e.target);

  // Send to server (example)
  fetch('/appointments/create', {
      method: 'POST',
      body: formData
    })
    .then(response => response.json())
    .then(data => {
      if (data.success) {
        showNotification('Appointment scheduled successfully', 'success');
        e.target.reset();
      } else {
        showNotification('Failed to schedule appointment', 'error');
      }
    })
    .catch(error => {
      showNotification('An error occurred', 'error');
      console.error('Error:', error);
    });
}

// Handle File Preview
function handleFilePreview(e) {
  const file = e.target.files[0];
  const previewContainer = document.getElementById('file-preview');

  if (previewContainer && file) {
    if (file.type.startsWith('image/')) {
      const reader = new FileReader();
      reader.onload = function(e) {
        previewContainer.innerHTML = `
                    <img src="${e.target.result}" alt="Preview" style="max-width: 200px;">
                `;
      }
      reader.readAsDataURL(file);
    } else {
      previewContainer.innerHTML = `
                <div class="file-info">
                    <p>File: ${file.name}</p>
                    <p>Size: ${(file.size / 1024).toFixed(2)} KB</p>
                </div>
            `;
    }
  }
}

// Show Notification
function showNotification(message, type) {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;
  notification.textContent = message;

  document.body.appendChild(notification);

  setTimeout(() => {
    notification.remove();
  }, 3000);
}