<?php
require_once 'includes/config.php';
require_once 'includes/functions.php';

if (!isLoggedIn()) {
    header('Location: login.php');
    exit();
}

$userId = $_SESSION['user_id'];
$userRole = $_SESSION['user_role'];

// معالجة إنشاء موعد جديد
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $appointmentData = [
        'patient_id' => $userRole === 'patient' ? $userId : $_POST['patient_id'],
        'doctor_id' => $userRole === 'doctor' ? $userId : $_POST['doctor_id'],
        'date' => $_POST['date'],
        'time' => $_POST['time'],
        'reason' => sanitizeInput($_POST['reason'])
    ];

    if (createAppointment($appointmentData)) {
        flashMessage('تم إنشاء الموعد بنجاح', 'success');
    } else {
        flashMessage('حدث خطأ أثناء إنشاء الموعد', 'error');
    }
}

// جلب المواعيد الحالية
$appointments = getAppointments($userId, $userRole);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>المواعيد - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <header class="header">
        <div class="container">
            <nav class="nav">
                <div class="nav-logo"><?php echo SITE_NAME; ?></div>
                <ul class="nav-menu">
                    <li><a href="dashboard.php" class="nav-link">لوحة التحكم</a></li>
                    <li><a href="appointments.php" class="nav-link">المواعيد</a></li>
                    <li><a href="logout.php" class="nav-link">تسجيل الخروج</a></li>
                </ul>
            </nav>
        </div>
    </header>

    <main class="main">
        <div class="container">
            <h2>إدارة المواعيد</h2>

            <?php $flash = getFlashMessage(); ?>
            <?php if ($flash): ?>
                <div class="alert alert-<?php echo $flash['type']; ?>">
                    <?php echo $flash['message']; ?>
                </div>
            <?php endif; ?>

            <div class="appointments-container">
                <!-- نموذج إنشاء موعد جديد -->
                <div class="form-container">
                    <h3>حجز موعد جديد</h3>
                    <form method="POST" action="">
                        <?php if ($userRole === 'patient'): ?>
                            <div class="form-group">
                                <label for="doctor_id">اختر الطبيب</label>
                                <select name="doctor_id" id="doctor_id" class="form-input" required>
                                    <?php
                                    // هنا يجب إضافة قائمة الأطباء من قاعدة البيانات
                                    $doctors = getDoctors();
                                    foreach ($doctors as $doctor): ?>
                                        <option value="<?php echo $doctor['id']; ?>">
                                            <?php echo $doctor['name']; ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="date">التاريخ</label>
                            <input type="date" id="date" name="date" class="form-input" required>
                        </div>

                        <div class="form-group">
                            <label for="time">الوقت</label>
                            <input type="time" id="time" name="time" class="form-input" required>
                        </div>

                        <div class="form-group">
                            <label for="reason">سبب الزيارة</label>
                            <textarea id="reason" name="reason" class="form-input" rows="3"></textarea>
                        </div>

                        <button type="submit" class="form-button">حجز الموعد</button>
                    </form>
                </div>

                <!-- عرض المواعيد الحالية -->
                <div class="appointments-list">
                    <h3>المواعيد الحالية</h3>
                    <?php if (!empty($appointments)): ?>
                        <table class="appointments-table">
                            <thead>
                                <tr>
                                    <th>التاريخ</th>
                                    <th>الوقت</th>
                                    <?php if ($userRole === 'doctor'): ?>
                                        <th>المريض</th>
                                    <?php else: ?>
                                        <th>الطبيب</th>
                                    <?php endif; ?>
                                    <th>الحالة</th>
                                    <th>الإجراءات</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($appointments as $appointment): ?>
                                    <tr>
                                        <td><?php echo $appointment['appointment_date']; ?></td>
                                        <td><?php echo $appointment['appointment_time']; ?></td>
                                        <td>
                                            <?php echo $userRole === 'doctor' ? 
                                                $appointment['patient_name'] : 
                                                $appointment['doctor_name']; ?>
                                        </td>
                                        <td><?php echo $appointment['status']; ?></td>
                                        <td>
                                            <?php if ($appointment['status'] === 'pending'): ?>
                                                <button class="btn-cancel" 
                                                        onclick="cancelAppointment(<?php echo $appointment['id']; ?>)">
                                                    إلغاء
                                                </button>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php else: ?>
                        <p>لا توجد مواعيد حالية</p>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </main>

    <script src="assets/js/main.js"></script>
</body>
</html>