<?php
require_once 'includes/config.php';
require_once 'includes/functions.php';

if (!isLoggedIn()) {
    header('Location: login.php');
    exit();
}

$userId = $_SESSION['user_id'];
$userRole = $_SESSION['user_role'];
$appointments = getAppointments($userId, $userRole);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>لوحة التحكم - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <header class="header">
        <div class="container">
            <nav class="nav">
                <div class="nav-logo"><?php echo SITE_NAME; ?></div>
                <ul class="nav-menu">
                    <li><a href="dashboard.php" class="nav-link">لوحة التحكم</a></li>
                    <li><a href="appointments.php" class="nav-link">المواعيد</a></li>
                    <li><a href="logout.php" class="nav-link">تسجيل الخروج</a></li>
                </ul>
            </nav>
        </div>
    </header>

    <main class="dashboard">
        <div class="container">
            <h2>مرحباً، <?php echo $_SESSION['user_name']; ?></h2>

            <div class="dashboard-grid">
                <div class="dashboard-card">
                    <h3>المواعيد القادمة</h3>
                    <?php if (!empty($appointments)): ?>
                        <ul class="appointments-list">
                            <?php foreach ($appointments as $appointment): ?>
                                <li class="appointment-item">
                                    <div class="appointment-info">
                                        <p>التاريخ: <?php echo $appointment['appointment_date']; ?></p>
                                        <p>الوقت: <?php echo $appointment['appointment_time']; ?></p>
                                        <?php if ($userRole === 'doctor'): ?>
                                            <p>المريض: <?php echo $appointment['patient_name']; ?></p>
                                        <?php else: ?>
                                            <p>الطبيب: <?php echo $appointment['doctor_name']; ?></p>
                                        <?php endif; ?>
                                    </div>
                                    <div class="appointment-status <?php echo $appointment['status']; ?>">
                                        <?php echo $appointment['status']; ?>
                                    </div>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    <?php else: ?>
                        <p>لا توجد مواعيد قادمة</p>
                    <?php endif; ?>
                </div>

                <?php if ($userRole === 'patient'): ?>
                <div class="dashboard-card">
                    <h3>الملفات الطبية</h3>
                    <form action="upload.php" method="POST" enctype="multipart/form-data">
                        <div class="form-group">
                            <label for="file">رفع ملف طبي</label>
                            <input type="file" id="file" name="file" class="form-input">
                        </div>
                        <button type="submit" class="form-button">رفع</button>
                    </form>
                </div>
                <?php endif; ?>
            </div>
        </div>
    </main>

    <script src="assets/js/main.js"></script>
</body>
</html>