<?php
require_once 'includes/config.php';
require_once 'includes/functions.php';

if (isLoggedIn()) {
    header('Location: dashboard.php');
    exit();
}

$errors = [];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $userData = [
        'name' => sanitizeInput($_POST['name']),
        'email' => sanitizeInput($_POST['email']),
        'password' => $_POST['password'],
        'password_confirm' => $_POST['password_confirm'],
        'role' => sanitizeInput($_POST['role'])
    ];

    // التحقق من صحة البيانات
    if (empty($userData['name']) || empty($userData['email']) || 
        empty($userData['password']) || empty($userData['role'])) {
        $errors[] = 'جميع الحقول مطلوبة';
    }

    if ($userData['password'] !== $userData['password_confirm']) {
        $errors[] = 'كلمات المرور غير متطابقة';
    }

    if (strlen($userData['password']) < 6) {
        $errors[] = 'يجب أن تكون كلمة المرور 6 أحرف على الأقل';
    }

    if (empty($errors)) {
        if (registerUser($userData)) {
            header('Location: login.php');
            exit();
        } else {
            $errors[] = 'حدث خطأ أثناء التسجيل';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>التسجيل - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="assets/css/style.css">
</head>
<body>
    <div class="container">
        <div class="form-container">
            <h2>إنشاء حساب جديد</h2>

            <?php if (!empty($errors)): ?>
                <div class="error-messages">
                    <?php foreach ($errors as $error): ?>
                        <div class="error"><?php echo $error; ?></div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>

            <form method="POST" action="">
                <div class="form-group">
                    <label for="name">الاسم الكامل</label>
                    <input type="text" id="name" name="name" class="form-input" required>
                </div>

                <div class="form-group">
                    <label for="email">البريد الإلكتروني</label>
                    <input type="email" id="email" name="email" class="form-input" required>
                </div>

                <div class="form-group">
                    <label for="password">كلمة المرور</label>
                    <input type="password" id="password" name="password" class="form-input" required>
                </div>

                <div class="form-group">
                    <label for="password_confirm">تأكيد كلمة المرور</label>
                    <input type="password" id="password_confirm" name="password_confirm" class="form-input" required>
                </div>

                <div class="form-group">
                    <label for="role">نوع الحساب</label>
                    <select id="role" name="role" class="form-input" required>
                        <option value="patient">مريض</option>
                        <option value="doctor">طبيب</option>
                    </select>
                </div>

                <button type="submit" class="form-button">تسجيل</button>
            </form>

            <p class="form-footer">
                لديك حساب بالفعل؟ <a href="login.php">تسجيل الدخول</a>
            </p>
        </div>
    </div>
</body>
</html>